Range-v3: ranges::v3::concepts::InsertableIterable Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::concepts::InsertableIterable Struct Reference
Concepts
Inheritance diagram for ranges::v3::concepts::InsertableIterable:

## Public Member Functions
template<typename Rng , typename... Rest>
auto | requires_ (Rng &&rng, Rest &&...rest) -> decltype(concepts::valid_expr((ranges::insert(std::forward< Rng >(rng), std::forward< Rest >(rest)...), 42)))
Public Member Functions inherited from ranges::v3::concepts::refines< Iterable(_1)>
void | requires_ (Ts &&...)

## Additional Inherited Members
Public Types inherited from ranges::v3::concepts::refines< Iterable(_1)>
using | base_concepts_t = meta::list< Concepts...>